@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2007 Sun Microsystems Inc.
+# Copyright 2004-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Utilities to manage the writing of the user application specific
 preferences files.
@@ -24,7 +24,7 @@ preferences files.
 __id__        = "$Id$"
 __version__   = "$Revision:$"
 __date__      = "$Date:$"
-__copyright__ = "Copyright (c) 2007 Sun Microsystems Inc."
+__copyright__ = "Copyright (c) 2007-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import os
@@ -125,8 +125,8 @@ class OrcaPrefs(orca_prefs.OrcaPrefs):
         - value: the replace string to use.
         """
 
-        prefs.writelines("    orca.pronunciation_dict.setPronunciation(\"" + \
-                    word + "\", \"" + value + "\", pronunciations)\n")
+        prefs.writelines("    orca.pronunciation_dict.setPronunciation(" + \
+                    repr(word) + ", " + repr(value) + ", pronunciations)\n")
 
     def _writePronunciationMap(self, prefs, treeModel):
         """Write to configuration file 'prefs' the new application specific
@@ -176,12 +176,15 @@ class OrcaPrefs(orca_prefs.OrcaPrefs):
         prefs.writelines("except ImportError:\n")
         prefs.writelines("    pass\n")
 
-    def _writePreferences(self):
+    def writePreferences(self):
         """Creates the directory and files to hold application specific
         user preferences.  Write out any preferences that are different
         from the generic Orca preferences for this user. Note that callers
         of this method may want to consider using an ordered dictionary so
         that the keys are output in a deterministic order.
+
+        Returns True if the user needs to log out for accessibility
+        settings to take effect.
         """
 
         self._setupPreferencesDirs()
@@ -216,6 +219,7 @@ class OrcaPrefs(orca_prefs.OrcaPrefs):
 
         self._writeAppPreferencesPostamble(prefs, self.appName)
         prefs.close()
+        return False # no logout is needed
 
 def writePreferences(prefsDict, appName=None, appScript=None,
                      keyBindingsTreeModel=None,
@@ -235,8 +239,11 @@ def writePreferences(prefsDict, appName=None, appScript=None,
     writing out console preferences.
     - pronunciationTreeModel - pronunciation dictionary tree model, or
     None if we are writing out console preferences.
+
+    Returns True if the user needs to log out for accessibility settings
+    to take effect.
     """
 
-    OP = OrcaPrefs(prefsDict, appName, appScript, 
-                   keyBindingsTreeModel, pronunciationTreeModel)
-    OP._writePreferences()
+    orcaPrefs = OrcaPrefs(prefsDict, appName, appScript, 
+                          keyBindingsTreeModel, pronunciationTreeModel)
+    return orcaPrefs.writePreferences()
