@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """A very experimental approach to the refreshable Braille display.  This
 module treats each line of the display as a sequential set of regions, where
@@ -25,10 +25,10 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py 3831 2008-04-15 23:35:20Z eitani $"
-__version__   = "$Revision: 3831 $"
-__date__      = "$Date: 2008-04-15 19:35:20 -0400 (Tue, 15 Apr 2008) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id: braille.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import logging
@@ -36,8 +36,6 @@ log = logging.getLogger("braille")
 
 import signal
 
-import pyatspi
-
 try:
     import louis
 except ImportError:
@@ -467,6 +465,8 @@ class Text(Region):
         if orca_state.activeScript:
             [string, self.caretOffset, self.lineOffset] = \
                  orca_state.activeScript.getTextLineAtCaret(self.accessible)
+        else:
+            string = ""
 
         string = string.decode("UTF-8")
 
@@ -564,8 +564,27 @@ class Text(Region):
 
         attrIndicator = settings.textAttributesBrailleIndicator
         selIndicator = settings.brailleSelectorIndicator
+        linkIndicator = settings.brailleLinkIndicator
         script = orca_state.activeScript
 
+        if linkIndicator != settings.BRAILLE_LINK_NONE:
+            try:
+                hyperText = self.accessible.queryHypertext()
+                nLinks = hyperText.getNLinks()
+            except:
+                nLinks = 0
+
+            n = 0
+            while n < nLinks:
+                link = hyperText.getLink(n)
+                if self.lineOffset <= link.startIndex:
+                    for i in xrange(link.startIndex, link.endIndex):
+                        try:
+                            regionMask[i] |= linkIndicator
+                        except:
+                            pass
+                n += 1
+
         if attrIndicator:
             enabledAttributes = script.attribsToDictionary(
                 settings.enabledBrailledTextAttributes)
