@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Utilities for obtaining braille strings for objects.  In general,
 there probably should be a singleton instance of the BrailleGenerator
@@ -23,10 +23,10 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 3638 2008-02-25 21:50:59Z joanied $"
-__version__   = "$Revision: 3638 $"
-__date__      = "$Date: 2008-02-25 16:50:59 -0500 (Mon, 25 Feb 2008) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id: braillegenerator.py 3910 2008-05-20 20:40:55Z joanied $"
+__version__   = "$Revision: 3910 $"
+__date__      = "$Date: 2008-05-20 16:40:55 -0400 (Tue, 20 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import pyatspi
@@ -37,6 +37,7 @@ import rolenames
 import settings
 
 from orca_i18n import _                     # for gettext support
+from orca_i18n import ngettext              # for ngettext support
 
 class BrailleGenerator:
     """Takes accessible objects and produces a list of braille Regions
@@ -534,7 +535,38 @@ class BrailleGenerator:
 
         self._debugGenerator("_getBrailleRegionsForFrame", obj)
 
-        return self._getDefaultBrailleRegions(obj)
+        regions = []
+
+        text = ""
+        text = self._script.appendString(
+            text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(
+            text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text,
+                                         self._script.getTextForValue(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
+
+        # If this application has more than one unfocused alert or
+        # dialog window, then add '(<m> dialogs)' to the braille context,
+        # to let the user know.
+        #
+        alertAndDialogCount = \
+                    self._script.getUnfocusedAlertAndDialogCount(obj)
+        if alertAndDialogCount > 0:
+            # Translators: this tells the user how many unfocused
+            # alert and dialog windows plus the total number of
+            # windows that this application has.
+            #
+            line = ngettext("(%d dialog)",
+                            "(%d dialogs)",
+                            alertAndDialogCount) % alertAndDialogCount
+            text = self._script.appendString(text, line)
+
+        regions = []
+        componentRegion = braille.Component(obj, text)
+        regions.append(componentRegion)
+
+        return [regions, componentRegion]
 
     def _getBrailleRegionsForHtmlContainer(self, obj):
         """Get the braille for an HTML container.
@@ -1165,7 +1197,11 @@ class BrailleGenerator:
                     continue
                 else:
                     for j in range(0, action.nActions):
-                        if action.getName(j) == "toggle":
+                        # Translators: this is the action name for
+                        # the 'toggle' action. It must be the same
+                        # string used in the *.po file for gail.
+                        #
+                        if action.getName(j) in ["toggle", _("toggle")]:
                             hasToggle[i] = True
                             break
 
@@ -1201,7 +1237,12 @@ class BrailleGenerator:
                 debug.println(debug.LEVEL_FINEST,
                     "braillegenerator._getBrailleRegionsForTableCell " \
                     + "looking at action %d" % i)
-                if action.getName(i) == "toggle":
+
+                # Translators: this is the action name for
+                # the 'toggle' action. It must be the same
+                # string used in the *.po file for gail.
+                #
+                if action.getName(i) in ["toggle", _("toggle")]:
                     regions = self._getBrailleRegionsForCheckBox(obj)
 
                     # If this table cell doesn't have any label associated
@@ -1213,7 +1254,8 @@ class BrailleGenerator:
 
                     if label == None or len(label) == 0:
                         table = obj.parent.queryTable()
-                        n = table.getColumnAtIndex(obj.getIndexInParent())
+                        index = self._script.getCellIndex(obj)
+                        n = table.getColumnAtIndex(index)
                         accHeader = table.getColumnHeader(n)
                         regions[0].append(braille.Region(" "))
                         label = accHeader.name
@@ -1299,9 +1341,9 @@ class BrailleGenerator:
             savedBrailleVerbosityLevel = settings.brailleVerbosityLevel
             settings.brailleVerbosityLevel = \
                                          settings.VERBOSITY_LEVEL_BRIEF
-
-            row = table.getRowAtIndex(obj.getIndexInParent())
-            column = table.getColumnAtIndex(obj.getIndexInParent())
+            index = self._script.getCellIndex(obj)
+            row = table.getRowAtIndex(index)
+            column = table.getColumnAtIndex(index)
 
             # This is an indication of whether we should speak all the
             # table cells (the user has moved focus up or down a row),
@@ -1646,7 +1688,8 @@ class BrailleGenerator:
         except (NotImplementedError, AttributeError):
             table = None
         if parent and table:
-            row = table.getRowAtIndex(obj.getIndexInParent())
+            index = self._script.getCellIndex(obj)
+            row = table.getRowAtIndex(index)
             if (row >= 0) \
                 and (not obj.getRole() in [pyatspi.ROLE_ROW_HEADER,
                                            pyatspi.ROLE_TABLE_ROW_HEADER]):
@@ -1667,7 +1710,7 @@ class BrailleGenerator:
                     text = desc
                 regions.append(braille.Region(text))
 
-            col = table.getColumnAtIndex(obj.getIndexInParent())
+            col = table.getColumnAtIndex(index)
             if (col >= 0) \
                 and (not obj.getRole() in [pyatspi.ROLE_COLUMN_HEADER,
                                            pyatspi.ROLE_TABLE_COLUMN_HEADER]):
