@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Google Inc.
+# Copyright 2005-2008 Google Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 #
 """Python wrapper for Emacspeak speech servers.
 
@@ -38,11 +38,11 @@ emacspeak modules:
 
 """
 
-__id__ = "$Id: espeechfactory.py 3287 2007-11-29 21:46:14Z richb $"
+__id__ = "$Id: espeechfactory.py 3882 2008-05-07 18:22:10Z richb $"
 __author__ = "T. V. Raman"
-__version__ = "$Revision: 3287 $"
-__date__ = "$Date: 2007-11-29 16:46:14 -0500 (Thu, 29 Nov 2007) $"
-__copyright__ = "Copyright (c) 2005 Google Inc."
+__version__ = "$Revision: 3882 $"
+__date__ = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Google Inc."
 __license__ = "LGPL"
 __all__ = ['Speaker']
 
