@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,15 +14,15 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py 3845 2008-04-24 19:15:08Z wwalker $"
-__version__   = "$Revision: 3845 $"
-__date__      = "$Date: 2008-04-24 15:15:08 -0400 (Thu, 24 Apr 2008) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: gnomespeechfactory.py 3897 2008-05-16 16:30:44Z wwalker $"
+__version__   = "$Revision: 3897 $"
+__date__      = "$Date: 2008-05-16 12:30:44 -0400 (Fri, 16 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import logging
@@ -454,7 +454,7 @@ class SpeechServer(speechserver.SpeechServer):
         speaker = _Speaker(s._narrow(GNOME.Speech.Speaker))
 
         # Turn off punctuation.  We do this because we want to handle
-        # spoken punctuation on our own.  Only do so if "punctuation mode" 
+        # spoken punctuation on our own.  Only do so if "punctuation mode"
         # is available (see # bug #528797).
         #
         try:
@@ -542,6 +542,13 @@ class SpeechServer(speechserver.SpeechServer):
                             self.__sayAll.currentContext,
                             speechserver.SayAllContext.COMPLETED)
                         self.__sayAll = None
+                    except:
+                        # This is here to deal with the situation where speech
+                        # might have stopped and __sayAll was set to None.
+                        # If we don't handle those cases, Say All can stop
+                        # working.
+                        #
+                        pass
 
         rerun = True
 
@@ -645,7 +652,7 @@ class SpeechServer(speechserver.SpeechServer):
                      used to augment/override the default
                      voice settings.
         """
-        self.speak(character, acss)
+        self.speak(chnames.getCharacterName(character), acss)
 
     def speakUtterances(self, utterances, acss=None, interrupt=True):
         """Speaks the given list of utterances immediately.
@@ -874,6 +881,13 @@ class SpeechServer(speechserver.SpeechServer):
         if self.__sayAll:
             self.stop()
 
+        if not acss and text and text.isupper():
+            try:
+                acss = \
+                    orca_state.activeScript.voices[settings.UPPERCASE_VOICE]
+            except:
+                pass
+
         self.__speak(text, acss, interrupt)
 
     def isSpeaking(self):
