@@ -19,9 +19,9 @@
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__        = "$Id: orca.py 3928 2008-05-27 15:49:33Z richb $"
+__version__   = "$Revision: 3928 $"
+__date__      = "$Date: 2008-05-27 11:49:33 -0400 (Tue, 27 May 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -157,7 +157,12 @@ def getScriptForApp(app):
 
     Returns a Script instance.
     """
-    return _PRESENTATION_MANAGERS[_currentPresentationManager].getScript(app)
+
+    script = None
+    if _currentPresentationManager >= 0:
+        script = \
+            _PRESENTATION_MANAGERS[_currentPresentationManager].getScript(app)
+    return script
 
 ########################################################################
 #                                                                      #
@@ -679,9 +684,9 @@ def _processKeyboardEvent(event):
 
     # See if this is one of our special Orca modifier keys.
     #
-    # Just looking at the keycode should suffice, but there is a 
-    # "feature" in the Java Access Bridge where it chooses to emit 
-    # Java platform-independent keycodes instead of the keycodes 
+    # Just looking at the keycode should suffice, but there is a
+    # "feature" in the Java Access Bridge where it chooses to emit
+    # Java platform-independent keycodes instead of the keycodes
     # for the base platform:
     #
     # http://bugzilla.gnome.org/show_bug.cgi?id=106004
@@ -934,7 +939,6 @@ def loadUserSettings(script=None, inputEvent=None):
         debug.println(debug.LEVEL_CONFIGURATION,
                       "Magnification module has NOT been initialized.")
 
-
     # I'm not sure where else this should go. But it doesn't really look
     # right here.
     try:
@@ -1060,7 +1064,7 @@ def helpForOrca(script=None, inputEvent=None):
 
     props = { gnome.PARAM_APP_DATADIR : '/usr/share'}
     prog = gnome.program_init('orca', '1.0', properties=props)
-    gnome.help_display_with_doc_id(prog, 'gnome-access-guide', 
+    gnome.help_display_with_doc_id(prog, 'gnome-access-guide',
                                          'gnome-access-guide', 'ats-2')
 
     return True
@@ -1185,7 +1189,7 @@ def start(registry):
 
     if settings.timeoutCallback and (settings.timeoutTime > 0):
         signal.alarm(0)
-    
+
     if settings.cacheValues:
         pyatspi.setCacheLevel(pyatspi.CACHE_PROPERTIES)
 
@@ -1313,7 +1317,7 @@ def usage():
     print _("Usage: orca [OPTION...]")
     print
 
-    # Translators: this is the description of the command line option 
+    # Translators: this is the description of the command line option
     # '-?, --help' that is used to display usage information.
     #
     print "-?, --help                   " + _("Show this help message")
@@ -1321,22 +1325,22 @@ def usage():
     print "-v, --version                %s" % platform.version
 
     # Translators: this is the description of the command line option
-    # '-s, --setup, --gui-setup' that will initially display a GUI dialog 
+    # '-s, --setup, --gui-setup' that will initially display a GUI dialog
     # that would allow the user to set their Orca preferences.
     #
     print "-s, --setup, --gui-setup     " + _("Set up user preferences")
 
-    # Translators: this is the description of the command line option 
-    # '-t, --text-setup' that will initially display a list of questions 
-    # in text form, that the user will need to answer, before Orca will 
-    # startup. For this to happen properly, Orca will need to be run 
+    # Translators: this is the description of the command line option
+    # '-t, --text-setup' that will initially display a list of questions
+    # in text form, that the user will need to answer, before Orca will
+    # startup. For this to happen properly, Orca will need to be run
     # from a terminal window.
     #
     print "-t, --text-setup             " + \
           _("Set up user preferences (text version)")
 
-    # Translators: this is the description of the command line option 
-    # '-n, --no-setup' that means that Orca will startup without setting 
+    # Translators: this is the description of the command line option
+    # '-n, --no-setup' that means that Orca will startup without setting
     # up any user preferences.
     #
     print "-n, --no-setup               " +  \
@@ -1344,7 +1348,7 @@ def usage():
 
     # Translators: by default, Orca expects to find its user preferences
     # in a directory called .orca under the user's home directory. This
-    # is the description of the command line option 
+    # is the description of the command line option
     # '-u, --user-prefs-dir=dirname' that allows you to specify an alternate
     # location for those user preferences.
     #
@@ -1375,7 +1379,7 @@ def usage():
     # command line option, it will be automatically disabled as Orca is
     # started.
     #
-    print _("Prevent use of option") 
+    print _("Prevent use of option")
 
     # Translators: this is the Orca command line option that will quit Orca.
     # The user would run the Orca shell script again from a terminal window.
@@ -1387,14 +1391,14 @@ def usage():
 
     print
 
-    # Translators: this is text being sent to a terminal and we want to 
+    # Translators: this is text being sent to a terminal and we want to
     # keep the text lines within terminal boundaries.
     #
     print _("If Orca has not been previously set up by the user, Orca\n" \
             "will automatically launch the preferences set up unless\n" \
             "the -n or --no-setup option is used.")
 
-    # Translators: this is more text being sent to a terminal and we want to 
+    # Translators: this is more text being sent to a terminal and we want to
     # keep the text lines within terminal boundaries.
     #
     print
@@ -1505,7 +1509,7 @@ def main():
                 elif feature == Q_("option|braille"):
                     _commandLineSettings["enableBraille"] = True
 
-                # Translators: this option is for enabling a GUI to monitor 
+                # Translators: this option is for enabling a GUI to monitor
                 # what is being sent to the physical braille display.
                 #
                 # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
@@ -1513,7 +1517,7 @@ def main():
                 elif feature == Q_("option|braille-monitor"):
                     _commandLineSettings["enableBrailleMonitor"] = True
 
-                # Translators: this option is for enabling screen 
+                # Translators: this option is for enabling screen
                 # magnification.
                 #
                 # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
