@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2007 Sun Microsystems Inc.
+# Copyright 2004-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Each script maintains a set of key bindings, braille bindings, and
 AT-SPI event listeners.  The key bindings are an instance of
@@ -33,10 +33,10 @@ created in their own module.  The module defining the Script subclass
 is also required to have a 'getScript(app)' method that returns an
 instance of the Script subclass.  See default.py for an example."""
 
-__id__        = "$Id: script.py 3496 2008-01-24 17:40:12Z richb $"
-__version__   = "$Revision: 3496 $"
-__date__      = "$Date: 2008-01-24 12:40:12 -0500 (Thu, 24 Jan 2008) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id: script.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import braillegenerator
@@ -261,7 +261,14 @@ class Script:
         - appState: an object obtained from getAppState
         """
         return
-        
+
+    def getClickCount(self):
+        """Return the count of the number of clicks a user has made to one
+        of the keys on the keyboard.
+        """
+
+        return orca_state.clickCount
+
     # [[[WDW - There is a circular reference going on somewhere (see
     # bug 333168).  In the presence of this reference, the existence
     # of a __del__ method prevents the garbage collector from
@@ -319,6 +326,7 @@ class Script:
 
         Returns True if the event is of interest.
         """
+
         user_bindings = None
         user_bindings_map = settings.keyBindingsMap
         if user_bindings_map.has_key(self.__module__):
