@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Utilities for obtaining speech utterances for objects.  In general,
 there probably should be a singleton instance of the SpeechGenerator
@@ -23,10 +23,10 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py 3638 2008-02-25 21:50:59Z joanied $"
-__version__   = "$Revision: 3638 $"
-__date__      = "$Date: 2008-02-25 16:50:59 -0500 (Mon, 25 Feb 2008) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id: speechgenerator.py 3910 2008-05-20 20:40:55Z joanied $"
+__version__   = "$Revision: 3910 $"
+__date__      = "$Date: 2008-05-20 16:40:55 -0400 (Tue, 20 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import pyatspi
@@ -604,13 +604,33 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken for the object.
         """
 
-        # [[[TODO: richb - readjusted to just get the default speech instead
-        # of treating the frame like an alert and speaking all unrelated
-        # labels. We'll need to see if this has any adverse effects and
-        # adjust accordingly.]]]
-        #
-        utterances = self._getDefaultSpeech(obj, already_focused)
-        #utterances = self._getSpeechForAlert(obj, already_focused)
+        utterances = []
+
+        if not already_focused:
+            label = self._getSpeechForObjectLabel(obj)
+            utterances.extend(label)
+            name = self._getSpeechForObjectName(obj)
+            if name != label:
+                utterances.extend(name)
+            utterances.extend(self._getSpeechForAllTextSelection(obj))
+            utterances.extend(self._getSpeechForObjectRole(obj))
+
+            # If this application has more than one unfocused alert or
+            # dialog window, then speak '<m> unfocused dialogs'
+            # to let the user know.
+            #
+            alertAndDialogCount = \
+                        self._script.getUnfocusedAlertAndDialogCount(obj)
+            if alertAndDialogCount > 0:
+                # Translators: this tells the user how many unfocused
+                # alert and dialog windows that this application has.
+                #
+                line = ngettext("%d unfocused dialog",
+                                "%d unfocused dialogs",
+                                alertAndDialogCount) % alertAndDialogCount
+                utterances.append(line)
+
+        utterances.extend(self._getSpeechForObjectAvailability(obj))
 
         self._debugGenerator("_getSpeechForFrame",
                              obj,
@@ -1307,7 +1327,11 @@ class SpeechGenerator:
                     continue
                 else:
                     for j in range(0, action.nActions):
-                        if action.getName(j) == "toggle":
+                        # Translators: this is the action name for
+                        # the 'toggle' action. It must be the same
+                        # string used in the *.po file for gail.
+                        #
+                        if action.getName(j) in ["toggle", _("toggle")]:
                             hasToggle[i] = True
                             break
 
@@ -1342,7 +1366,12 @@ class SpeechGenerator:
                 debug.println(debug.LEVEL_FINEST,
                     "speechgenerator.__getTableCellUtterances " \
                     + "looking at action %d" % i)
-                if action.getName(i) == "toggle":
+
+                # Translators: this is the action name for
+                # the 'toggle' action. It must be the same
+                # string used in the *.po file for gail.
+                #
+                if action.getName(i) in ["toggle", _("toggle")]:
                     utterances = self._getSpeechForCheckBox(obj,
                                                             already_focused)
                     break
@@ -1427,8 +1456,9 @@ class SpeechGenerator:
             if settings.readTableCellRow and parent_table \
                 and (not self._script.isLayoutOnly(obj.parent)):
                 parent = obj.parent
-                row = parent_table.getRowAtIndex(obj.getIndexInParent())
-                column = parent_table.getColumnAtIndex(obj.getIndexInParent())
+                index = self._script.getCellIndex(obj)
+                row = parent_table.getRowAtIndex(index)
+                column = parent_table.getColumnAtIndex(index)
 
                 # This is an indication of whether we should speak all the
                 # table cells (the user has moved focus up or down a row),
@@ -1468,7 +1498,12 @@ class SpeechGenerator:
                                 action = None
                             if action and (label == None or len(label) == 0):
                                 for j in range(0, action.nActions):
-                                    if action.getName(j) == "toggle":
+                                    # Translators: this is the action name for
+                                    # the 'toggle' action. It must be the same
+                                    # string used in the *.po file for gail.
+                                    #
+                                    if action.getName(j) in ["toggle", \
+                                                             _("toggle")]:
                                         accHeader = \
                                             parent_table.getColumnHeader(i)
                                         utterances.append(accHeader.name)
