@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,15 +14,15 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Speaks information about the current object of interest."""
 
-__id__        = "$Id: where_am_I.py 3834 2008-04-17 18:22:54Z joanied $"
-__version__   = "$Revision: 3834 $"
-__date__      = "$Date: 2008-04-17 14:22:54 -0400 (Thu, 17 Apr 2008) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id: where_am_I.py 3910 2008-05-20 20:40:55Z joanied $"
+__version__   = "$Revision: 3910 $"
+__date__      = "$Date: 2008-05-20 16:40:55 -0400 (Tue, 20 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import pyatspi
@@ -127,7 +127,10 @@ class WhereAmI:
         elif role == pyatspi.ROLE_LIST_ITEM:
             self._speakListItem(obj, basicOnly)
 
-        elif role == pyatspi.ROLE_PARAGRAPH:
+        elif role in [pyatspi.ROLE_PARAGRAPH,
+                      pyatspi.ROLE_SECTION,
+                      pyatspi.ROLE_HEADING,
+                      pyatspi.ROLE_DOCUMENT_FRAME]:
             self._speakParagraph(obj, basicOnly)
 
         elif role == pyatspi.ROLE_ICON:
@@ -542,13 +545,14 @@ class WhereAmI:
             nColumns = 0
         else:
             nColumns = table.nColumns
-            column = table.getColumnAtIndex(obj.getIndexInParent())
+            index = self._script.getCellIndex(obj)
+            column = table.getColumnAtIndex(index)
             header = table.getColumnHeader(column)
             if header:
                 text = self._getObjName(header)
                 utterances.append(text)
 
-            row = table.getRowAtIndex(obj.getIndexInParent())
+            row = table.getRowAtIndex(index)
             header = table.getRowHeader(row)
             if header:
                 text = self._getObjName(header)
@@ -716,8 +720,9 @@ class WhereAmI:
         if link_uri:
             link_uri_info = urlparse.urlparse(link_uri)
         else:
-            # something is wrong, just return
-            return
+            # It might be an anchor.  Try to speak the text.
+            #
+            return self._speakText(obj, basicOnly)
       
         # Try to get the URI of the active document and parse it
         doc_uri = self._script.getDocumentFrameURI()
@@ -1185,8 +1190,8 @@ class WhereAmI:
             debug.println(self._debugLevel, "??? parent=%s" % parent.getRole())
             return []
         else:
-            row = table.getRowAtIndex(obj.getIndexInParent())
-
+            index = self._script.getCellIndex(obj)
+            row = table.getRowAtIndex(index)
             for i in range(0, table.nColumns):
                 acc = table.getAccessibleAt(row, i)
                 utterances.append(self._getTableCell(acc))
@@ -1263,7 +1268,7 @@ class WhereAmI:
 
         return text
 
-    def _getTextSelection(self, obj):
+    def getTextSelection(self, obj):
         """Get the text selection for the given object.
 
         Arguments:
@@ -1280,12 +1285,12 @@ class WhereAmI:
             [startOffset, endOffset] = textObj.getSelection(i)
 
             debug.println(self._debugLevel,
-                "_getTextSelection: selection start=%d, end=%d" % \
+                "getTextSelection: selection start=%d, end=%d" % \
                 (startOffset, endOffset))
 
             selectedText = textObj.getText(startOffset, endOffset)
             debug.println(self._debugLevel,
-                "_getTextSelection: selected text=<%s>" % selectedText)
+                "getTextSelection: selected text=<%s>" % selectedText)
 
             if i > 0:
                 textContents += " "
@@ -1313,7 +1318,7 @@ class WhereAmI:
         text = obj.queryText()
         if text.getNSelections() > 0:
             [textContents, startOffset, endOffset] = \
-                                            self._getTextSelection(obj)
+                                            self.getTextSelection(obj)
 
         if not basicOnly:
             current = obj
@@ -1327,7 +1332,7 @@ class WhereAmI:
                         prevObjText = prevObj.queryText()
                         if prevObjText.getNSelections() > 0:
                             [newTextContents, start, end] = \
-                                         self._getTextSelection(prevObj)
+                                         self.getTextSelection(prevObj)
                             textContents = newTextContents + " " + textContents
                             current = prevObj
                             morePossibleSelections = True
@@ -1349,7 +1354,7 @@ class WhereAmI:
                         nextObjText = nextObj.queryText()
                         if nextObjText.getNSelections() > 0:
                             [newTextContents, start, end] = \
-                                         self._getTextSelection(nextObj)
+                                         self.getTextSelection(nextObj)
                             textContents += " " + newTextContents
                             current = nextObj
                             morePossibleSelections = True
@@ -1504,7 +1509,7 @@ class WhereAmI:
         textOffset = startOffset
 
         for i in range(0, len(line)):
-            attribs = self._getAttributesForChar(text, textOffset, line, i)
+            attribs = self._getAttributesForChar(obj, text, textOffset, line, i)
             debug.println(self._debugLevel,
                           "line attribs <%s>" % (attribs))
             if attribs:
@@ -1519,7 +1524,7 @@ class WhereAmI:
 
         return newLine
 
-    def _getAttributesForChar(self, text, textOffset, line, lineIndex):
+    def _getAttributesForChar(self, obj, text, textOffset, line, lineIndex):
 
         keys = [ "style", "weight", "underline" ]
         attribStr = ""
@@ -1556,6 +1561,15 @@ class WhereAmI:
                             attribStr += " "
                             attribStr += (key + " " + attribute)
 
+            # Also check to see if this is a hypertext link.
+            #
+            if self._script.getLinkIndex(obj, textOffset) >= 0:
+                attribStr += " "
+                # Translators: this indicates that this piece of
+                # text is a hypertext link.
+                #
+                attribStr += _("link")
+
             debug.println(self._debugLevel,
                           "char <%s>: %s" % (line[lineIndex], attribStr))
 
@@ -1590,7 +1604,9 @@ class WhereAmI:
         1. The contents of the title bar of the application main window
         2. If in a dialog box within an application, the contents of the
         title bar of the dialog box.
-        3. Orca will pause briefly between these two pieces of information
+        3. '<n> unfocused dialogs' if this application has more than
+           one unfocused alert or dialog window.
+        4. Orca will pause briefly between these two pieces of information
         so that the speech user can distinguish each.
         """
 
@@ -1605,6 +1621,17 @@ class WhereAmI:
             text = self.getObjLabelAndName(results[1])
             utterances.append(text)
 
+        alertAndDialogCount = \
+                    self._script.getUnfocusedAlertAndDialogCount(obj)
+        if alertAndDialogCount > 0:
+            # Translators: this tells the user how many unfocused
+            # alert and dialog windows that this application has.
+            #
+            line = ngettext("%d unfocused dialog",
+                            "%d unfocused dialogs",
+                            alertAndDialogCount) % alertAndDialogCount
+            utterances.append(line)
+
         debug.println(self._debugLevel, "titlebar utterances=%s" % \
                       utterances)
         speech.speakUtterances(utterances)
